local assets =
{ 
    Asset("ANIM", "anim/wizard_cap.zip"),
    Asset("ANIM", "anim/wizard_cap_swap.zip"), 

    Asset("ATLAS", "images/inventoryimages/wizard_cap.xml"),
    Asset("IMAGE", "images/inventoryimages/wizard_cap.tex"),
}

local prefabs = 
{
}

local function OnEquip(inst, owner) 
    owner.AnimState:OverrideSymbol("swap_hat", "wizard_cap_swap", "swap_hat")

    owner.AnimState:Show("HAT")
    owner.AnimState:Show("HAT_HAIR")
    owner.AnimState:Hide("HAIR_NOHAT")
    --owner.AnimState:Hide("HAIR")

    if owner:HasTag("player") then
        owner.AnimState:Hide("HEAD")
        owner.AnimState:Show("HEAD_HAT")
    end
end

local function OnUnequip(inst, owner) 
    owner.AnimState:Hide("HAT")
    owner.AnimState:Hide("HAT_HAIR")
    owner.AnimState:Show("HAIR_NOHAT")
    owner.AnimState:Show("HAIR")

    if owner:HasTag("player") then
        owner.AnimState:Show("HEAD")
        owner.AnimState:Hide("HEAD_HAT")
    end
end

local function OnTakeDamage(inst, damage_amount)
    local owner = inst.components.inventoryitem.owner
    if owner then
        local sanity = owner.components.sanity
        if sanity then
            local unsaneness = damage_amount * TUNING.ARMOR_SANITY_DMG_AS_SANITY
            sanity:DoDelta(-unsaneness, false)
        end
    end
end

local function fn()

    local inst = CreateEntity()
    
    inst.entity:AddTransform()
    inst.entity:AddAnimState()
    inst.entity:AddNetwork()

    MakeInventoryPhysics(inst)

    inst.AnimState:SetBank("wizard_cap")
    inst.AnimState:SetBuild("wizard_cap")
    inst.AnimState:PlayAnimation("idle")

    inst:AddTag("hat")

    if not TheWorld.ismastersim then
        return inst
    end

    inst.entity:SetPristine()

    inst:AddComponent("inspectable")

    inst:AddComponent("tradable")

    inst:AddComponent("inventoryitem")
    inst.components.inventoryitem.imagename = "wizard_cap"
    inst.components.inventoryitem.atlasname = "images/inventoryimages/wizard_cap.xml"
	inst.components.inventoryitem.keepondeath = true
	
    inst:AddComponent("equippable")
    inst.components.equippable.equipslot = EQUIPSLOTS.HEAD
    inst.components.equippable:SetOnEquip(OnEquip)
    inst.components.equippable:SetOnUnequip(OnUnequip)
	inst.components.equippable.dapperness = TUNING.DAPPERNESS_MED 
	
    MakeHauntableLaunch(inst)

	inst:AddComponent("waterproofer")
    inst.components.waterproofer:SetEffectiveness(TUNING.WATERPROOFNESS_MED)
	
	inst:AddComponent("insulator")
    inst.components.insulator:SetInsulation(TUNING.INSULATION_LARGE)
	inst:AddComponent("armor")
	inst.components.armor:InitCondition(3000, .25)
	
	if not inst.components.characterspecific then
    	inst:AddComponent("characterspecific")
	end

    inst.components.characterspecific:SetOwner("marisa")
    inst.components.characterspecific:SetStorable(true)
    inst.components.characterspecific:SetComment("这东西我拿不起.")
    return inst
end
if TUNING.LANG == 1 then
	STRINGS.NAMES.WIZARD_CAP = "Marisa's Hat"
	STRINGS.CHARACTERS.GENERIC.DESCRIBE.WIZARD_CAP = "My lovely hat as a magician！"
else
	STRINGS.NAMES.WIZARD_CAP = "魔理沙的帽子"
	STRINGS.CHARACTERS.GENERIC.DESCRIBE.WIZARD_CAP = "象征魔法使身份的可爱帽子！"
end


return  Prefab("common/inventory/wizard_cap", fn, assets, prefabs)